Class: Google::Cloud::Connectors::V1::AuthConfig::Oauth2JwtBearer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/connectors/v1/authconfig.rb

Overview

Parameters to support JSON Web Token (JWT) Profile for Oauth 2.0 Authorization Grant based authentication. See https://tools.ietf.org/html/rfc7523 for more details.

Defined Under Namespace

Classes: JwtClaims

Instance Attribute Summary collapse

Instance Attribute Details

#client_key::Google::Cloud::Connectors::V1::Secret

Returns Secret version reference containing a PKCS#8 PEM-encoded private key associated with the Client Certificate. This private key will be used to sign JWTs used for the jwt-bearer authorization grant. Specified in the form as: projects/*/secrets/*/versions/*.

Returns:

  • (::Google::Cloud::Connectors::V1::Secret)

    Secret version reference containing a PKCS#8 PEM-encoded private key associated with the Client Certificate. This private key will be used to sign JWTs used for the jwt-bearer authorization grant. Specified in the form as: projects/*/secrets/*/versions/*.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/connectors/v1/authconfig.rb', line 79

class Oauth2JwtBearer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # JWT claims used for the jwt-bearer authorization grant.
  # @!attribute [rw] issuer
  #   @return [::String]
  #     Value for the "iss" claim.
  # @!attribute [rw] subject
  #   @return [::String]
  #     Value for the "sub" claim.
  # @!attribute [rw] audience
  #   @return [::String]
  #     Value for the "aud" claim.
  class JwtClaims
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#jwt_claims::Google::Cloud::Connectors::V1::AuthConfig::Oauth2JwtBearer::JwtClaims

Returns JwtClaims providers fields to generate the token.

Returns:



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/connectors/v1/authconfig.rb', line 79

class Oauth2JwtBearer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # JWT claims used for the jwt-bearer authorization grant.
  # @!attribute [rw] issuer
  #   @return [::String]
  #     Value for the "iss" claim.
  # @!attribute [rw] subject
  #   @return [::String]
  #     Value for the "sub" claim.
  # @!attribute [rw] audience
  #   @return [::String]
  #     Value for the "aud" claim.
  class JwtClaims
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end