Class: Google::Cloud::Connectors::V1::Destination

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/connectors/v1/destination_config.rb

Instance Attribute Summary collapse

Instance Attribute Details

#host::String

Returns For publicly routable host.

Note: The following fields are mutually exclusive: host, service_attachment. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    For publicly routable host.

    Note: The following fields are mutually exclusive: host, service_attachment. If a field in that set is populated, all other fields in the set will automatically be cleared.



50
51
52
53
# File 'proto_docs/google/cloud/connectors/v1/destination_config.rb', line 50

class Destination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#port::Integer

Returns The port is the target port number that is accepted by the destination.

Returns:

  • (::Integer)

    The port is the target port number that is accepted by the destination.



50
51
52
53
# File 'proto_docs/google/cloud/connectors/v1/destination_config.rb', line 50

class Destination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_attachment::String

Returns PSC service attachments. Format: projects//regions//serviceAttachments/*

Note: The following fields are mutually exclusive: service_attachment, host. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    PSC service attachments. Format: projects//regions//serviceAttachments/*

    Note: The following fields are mutually exclusive: service_attachment, host. If a field in that set is populated, all other fields in the set will automatically be cleared.



50
51
52
53
# File 'proto_docs/google/cloud/connectors/v1/destination_config.rb', line 50

class Destination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end