Class: Google::Cloud::Connectors::V1::DestinationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/connectors/v1/destination_config.rb

Overview

Define the Connectors target endpoint.

Instance Attribute Summary collapse

Instance Attribute Details

#destinations::Array<::Google::Cloud::Connectors::V1::Destination>

Returns The destinations for the key.

Returns:



31
32
33
34
# File 'proto_docs/google/cloud/connectors/v1/destination_config.rb', line 31

class DestinationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#key::String

Returns The key is the destination identifier that is supported by the Connector.

Returns:

  • (::String)

    The key is the destination identifier that is supported by the Connector.



31
32
33
34
# File 'proto_docs/google/cloud/connectors/v1/destination_config.rb', line 31

class DestinationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end