Class: Google::Cloud::Connectors::V1::RuntimeEntitySchema::Field

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/connectors/v1/connection.rb

Overview

Metadata of an entity field.

Instance Attribute Summary collapse

Instance Attribute Details

#additional_details::Google::Protobuf::Struct

Returns The following map contains fields that are not explicitly mentioned above,this give connectors the flexibility to add new metadata fields.

Returns:

  • (::Google::Protobuf::Struct)

    The following map contains fields that are not explicitly mentioned above,this give connectors the flexibility to add new metadata fields.



201
202
203
204
# File 'proto_docs/google/cloud/connectors/v1/connection.rb', line 201

class Field
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_type::Google::Cloud::Connectors::V1::DataType

Returns The data type of the Field.

Returns:



201
202
203
204
# File 'proto_docs/google/cloud/connectors/v1/connection.rb', line 201

class Field
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#default_value::Google::Protobuf::Value

Returns The following field specifies the default value of the Field provided by the external system if a value is not provided.

Returns:

  • (::Google::Protobuf::Value)

    The following field specifies the default value of the Field provided by the external system if a value is not provided.



201
202
203
204
# File 'proto_docs/google/cloud/connectors/v1/connection.rb', line 201

class Field
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns A brief description of the Field.

Returns:

  • (::String)

    A brief description of the Field.



201
202
203
204
# File 'proto_docs/google/cloud/connectors/v1/connection.rb', line 201

class Field
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#field::String

Returns Name of the Field.

Returns:

  • (::String)

    Name of the Field.



201
202
203
204
# File 'proto_docs/google/cloud/connectors/v1/connection.rb', line 201

class Field
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#key::Boolean

Returns The following boolean field specifies if the current Field acts as a primary key or id if the parent is of type entity.

Returns:

  • (::Boolean)

    The following boolean field specifies if the current Field acts as a primary key or id if the parent is of type entity.



201
202
203
204
# File 'proto_docs/google/cloud/connectors/v1/connection.rb', line 201

class Field
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#nullable::Boolean

Returns Specifies whether a null value is allowed.

Returns:

  • (::Boolean)

    Specifies whether a null value is allowed.



201
202
203
204
# File 'proto_docs/google/cloud/connectors/v1/connection.rb', line 201

class Field
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#readonly::Boolean

Returns Specifies if the Field is readonly.

Returns:

  • (::Boolean)

    Specifies if the Field is readonly.



201
202
203
204
# File 'proto_docs/google/cloud/connectors/v1/connection.rb', line 201

class Field
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end