Class: Google::Cloud::Connectors::V1::ConfigVariable
- Inherits:
-
Object
- Object
- Google::Cloud::Connectors::V1::ConfigVariable
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/connectors/v1/common.rb
Overview
ConfigVariable represents a configuration variable present in a Connection. or AuthConfig.
Instance Attribute Summary collapse
-
#bool_value ⇒ ::Boolean
Value is a bool.
-
#int_value ⇒ ::Integer
Value is an integer.
-
#key ⇒ ::String
Key of the config variable.
-
#secret_value ⇒ ::Google::Cloud::Connectors::V1::Secret
Value is a secret.
-
#string_value ⇒ ::String
Value is a string.
Instance Attribute Details
#bool_value ⇒ ::Boolean
Returns Value is a bool.
Note: The following fields are mutually exclusive: bool_value, int_value, string_value, secret_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
182 183 184 185 |
# File 'proto_docs/google/cloud/connectors/v1/common.rb', line 182 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#int_value ⇒ ::Integer
Returns Value is an integer
Note: The following fields are mutually exclusive: int_value, bool_value, string_value, secret_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
182 183 184 185 |
# File 'proto_docs/google/cloud/connectors/v1/common.rb', line 182 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#key ⇒ ::String
Returns Key of the config variable.
182 183 184 185 |
# File 'proto_docs/google/cloud/connectors/v1/common.rb', line 182 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#secret_value ⇒ ::Google::Cloud::Connectors::V1::Secret
Returns Value is a secret.
Note: The following fields are mutually exclusive: secret_value, int_value, bool_value, string_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
182 183 184 185 |
# File 'proto_docs/google/cloud/connectors/v1/common.rb', line 182 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#string_value ⇒ ::String
Returns Value is a string.
Note: The following fields are mutually exclusive: string_value, int_value, bool_value, secret_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
182 183 184 185 |
# File 'proto_docs/google/cloud/connectors/v1/common.rb', line 182 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |