Class: Google::Cloud::Connectors::V1::DestinationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Connectors::V1::DestinationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/connectors/v1/destination_config.rb
Overview
Define the Connectors target endpoint.
Instance Attribute Summary collapse
-
#destinations ⇒ ::Array<::Google::Cloud::Connectors::V1::Destination>
The destinations for the key.
-
#key ⇒ ::String
The key is the destination identifier that is supported by the Connector.
Instance Attribute Details
#destinations ⇒ ::Array<::Google::Cloud::Connectors::V1::Destination>
Returns The destinations for the key.
31 32 33 34 |
# File 'proto_docs/google/cloud/connectors/v1/destination_config.rb', line 31 class DestinationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#key ⇒ ::String
Returns The key is the destination identifier that is supported by the Connector.
31 32 33 34 |
# File 'proto_docs/google/cloud/connectors/v1/destination_config.rb', line 31 class DestinationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |